cmd

package
v0.0.0-...-07df6e4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 14, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	BuildTime string
	Version   string
)
var (

	// Logger is a dedicated Logger that should receive all messages that go to stdout
	Logger *slog.Logger
)
var RootCmd = &cobra.Command{
	Use:              "nukictl",
	Short:            "Command line tool to manage and control Nuki devices and online services.",
	TraverseChildren: true,
}

RootCmd represents the base command when called without any subcommands

Functions

func Execute

func Execute(l *slog.LevelVar)

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

Types

This section is empty.

Directories

Path Synopsis

Jump to